package com.bonus.canteen.core.menu.service;

import java.util.List;

import com.bonus.canteen.core.menu.domain.MenuNutritionType;
import com.bonus.canteen.core.menu.vo.NutritionTypeV2VO;
import com.bonus.canteen.core.menu.vo.NutritionTypeVo;

/**
 * 营养基础类型Service接口
 *
 * @author xsheng
 * @date 2025-04-03
 */
public interface IMenuNutritionTypeService {
    /**
     * 查询营养基础类型
     *
     * @param id 营养基础类型主键
     * @return 营养基础类型
     */
    public MenuNutritionType selectMenuNutritionTypeById(Long id);

    /**
     * 查询营养基础类型列表
     *
     * @param menuNutritionType 营养基础类型
     * @return 营养基础类型集合
     */
    public List<MenuNutritionType> selectMenuNutritionTypeList(MenuNutritionType menuNutritionType);

    /**
     * 新增营养基础类型
     *
     * @param menuNutritionType 营养基础类型
     * @return 结果
     */
    public int insertMenuNutritionType(MenuNutritionType menuNutritionType);

    /**
     * 修改营养基础类型
     *
     * @param menuNutritionType 营养基础类型
     * @return 结果
     */
    public int updateMenuNutritionType(MenuNutritionType menuNutritionType);

    /**
     * 批量删除营养基础类型
     *
     * @param ids 需要删除的营养基础类型主键集合
     * @return 结果
     */
    public int deleteMenuNutritionTypeByIds(Integer[] ids);

    /**
     * 删除营养基础类型信息
     *
     * @param id 营养基础类型主键
     * @return 结果
     */
    public int deleteMenuNutritionTypeById(Long id);

    List<NutritionTypeV2VO> getNutritionTypeList();
}
